==> lima-swing-0.7.3-sources.jar: org/chorem/lima/ui/common/TableModelWithGroup.java <==
package org.chorem.lima.ui.common;

/*
 * #%L
 * Lima :: Swing
 * $Id: TableModelWithGroup.java 3751 2014-03-05 11:59:43Z sbavencoff $
 * $HeadURL: https://svn.chorem.org/lima/tags/lima-0.7.3/lima-swing/src/main/java/org/chorem/lima/ui/common/TableModelWithGroup.java $
 * %%
 * Copyright (C) 2008 - 2013 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

/**
 * @author Sylvain Bavencoff <bavencoff@codelutin.com>
 */
public abstract class TableModelWithGroup<E> extends AbstractLimaTableModel<E> {

    public int indexGroupAt(int row) {
        int countGroup = 0;
        E precedingValue = get(0);
        for (int precedingRow = 1; precedingRow <= row; precedingRow++) {
            E value = get(precedingRow);
            if ( ! sameGroup(precedingValue, value)) {
                countGroup++;
            }
            precedingValue = value;
        }
        return countGroup;

    }

    public int indexInGroup(int row) {
        int index = 0;
        while (row-index > 0 && sameGroup(get(row), get(row-index-1)))  {
            index++;
        }
        return index;

    }

    public abstract boolean sameGroup(E e1, E e2);
}

==> lima-swing-0.8-sources.jar: org/chorem/lima/ui/common/TableModelWithGroup.java <==
package org.chorem.lima.ui.common;

/*
 * #%L
 * Lima :: Swing
 * %%
 * Copyright (C) 2008 - 2013 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

/**
 * @author Sylvain Bavencoff <bavencoff@codelutin.com>
 */
public abstract class TableModelWithGroup<E> extends AbstractLimaTableModel<E> {

    private static final long serialVersionUID = 2349944168938847283L;

    public int indexGroupAt(int row) {
        int countGroup = 0;
        E precedingValue = get(0);
        for (int precedingRow = 1; precedingRow <= row; precedingRow++) {
            E value = get(precedingRow);
            if ( ! sameGroup(precedingValue, value)) {
                countGroup++;
            }
            precedingValue = value;
        }
        return countGroup;

    }

    public int indexInGroup(int row) {
        int index = 0;
        while (row-index > 0 && sameGroup(get(row), get(row-index-1)))  {
            index++;
        }
        return index;

    }

    public abstract boolean sameGroup(E e1, E e2);
}
